Testing some badges provided by different services:

![Python package](https://github.com/Pythocrates/SPyKeS/workflows/Python%20package/badge.svg)
[![codecov](https://codecov.io/gh/Pythocrates/SPyKeS/branch/master/graph/badge.svg)](https://codecov.io/gh/Pythocrates/SPyKeS)
[![Test Coverage](https://api.codeclimate.com/v1/badges/0d092f8ca82f91264651/test_coverage)](https://codeclimate.com/github/Pythocrates/SPyKeS/test_coverage)
[![Maintainability](https://api.codeclimate.com/v1/badges/0d092f8ca82f91264651/maintainability)](https://codeclimate.com/github/Pythocrates/SPyKeS/maintainability)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Code Quality Score](https://www.code-inspector.com/project/13444/score/svg)](https://frontend.code-inspector.com/public/project/13444/SPyKeS/dashboard)
[![Code Grade](https://www.code-inspector.com/project/13444/status/svg)](https://frontend.code-inspector.com/public/project/13444/SPyKeS/dashboard)
[![Requirements Status](https://requires.io/github/Pythocrates/SPyKeS/requirements.svg?branch=master)](https://requires.io/github/Pythocrates/SPyKeS/requirements/?branch=master)

Some badges provided by shields.io

![PyPI](https://img.shields.io/pypi/v/spykeys?style=plastic)
![PyPI - Format](https://img.shields.io/pypi/format/spykeys?style=plastic)
![PyPI - License](https://img.shields.io/pypi/l/spykeys?style=plastic)
![PyPI - Status](https://img.shields.io/pypi/status/spykeys?style=plastic)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/spykeys?style=plastic)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/spykeys?style=plastic)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/spykeys?style=plastic)
![GitHub Release Date](https://img.shields.io/github/release-date/Pythocrates/SpyKeS?style=plastic)
![GitHub Commit Activity](https://img.shields.io/github/commit-activity/m/Pythocrates/SPyKeS?style=plastic)
![GitHub Last Commit](https://img.shields.io/github/last-commit/Pythocrates/SPyKeS?style=plastic)
![GitHub License](https://img.shields.io/github/license/Pythocrates/SPyKeS?style=plastic)
![GitHub commits since latest release (by date)](https://img.shields.io/github/commits-since/Pythocrates/SPyKeS/latest?style=plastic)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/Pythocrates/SPyKeS?style=plastic)
![GitHub milestones](https://img.shields.io/github/milestones/all/Pythocrates/SPyKeS?style=plastic)
![GitHub closed issues](https://img.shields.io/github/issues-closed/Pythocrates/SPyKeS?style=plastic)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/Pythocrates/SPyKeS?style=plastic)
![GitHub top language](https://img.shields.io/github/languages/top/Pythocrates/SPyKeS?style=plastic)

![Scrutinizer code quality (GitHub/Bitbucket)](https://img.shields.io/scrutinizer/quality/g/Pythocrates/SPyKeS)
![CodeFactor Grade](https://img.shields.io/codefactor/grade/github/Pythocrates/SPyKeS?style=plastic)

![Code Climate technical debt](https://img.shields.io/codeclimate/tech-debt/Pythocrates/SPyKeS?style=plastic)
![Code Climate maintainability](https://img.shields.io/codeclimate/maintainability-percentage/Pythocrates/SPyKeS?style=plastic)
![Code Climate issues](https://img.shields.io/codeclimate/issues/Pythocrates/SPyKeS?style=plastic)
![Code Climate technical debt](https://img.shields.io/codeclimate/tech-debt/Pythocrates/SPyKeS?style=plastic)

![Libraries.io dependency status for GitHub repo](https://img.shields.io/librariesio/github/Pythocrates/SPyKeS?style=plastic)
![Libraries.io SourceRank](https://img.shields.io/librariesio/sourcerank/pypi/spykeys?style=plastic)
![Requires.io](https://img.shields.io/requires/github/Pythocrates/SPyKeS?style=plastic)

[![Code Smells](https://sonarcloud.io/api/project_badges/measure?project=Pythocrates_SPyKeS&metric=code_smells)](https://sonarcloud.io/dashboard?id=Pythocrates_SPyKeS)


# SPyKeS
Simple Python Key Store

SPyKeS is a simple Python implementation of https://github.com/42ways/simple-keystore.
